@@ -17,6 +17,6 @@ setMethod("plot", "DistrList",
     function(x,y=NULL,...){ 
         for(i in 1:length(x)){
             get(getOption("device"))()
-            plot(x[[i]])
+            plot(x[[i]],...)
         }
     })
